@@ -34,3 +34,10 @@ PLIVO_AUTH_TOKEN = os.environ.get('PLIVO_AUTH_TOKEN', None)
 # # ------------ Twilio -----------
 TWILIO_ACCOUNT_SID = os.environ.get('TWILIO_ACCOUNT_SID', None)
 TWILIO_AUTH_TOKEN = os.environ.get('TWILIO_AUTH_TOKEN', None)
+
+# # ------------- MSg91 ------------
+MSG91_AUTHKEY = None
+MSG91_SMS_SEND_API = 'https://control.msg91.com/api/sendhttp.php?authkey={authkey}&mobiles={mobiles}&' \
+      'message={message}&sender={sender}&route={route}&country={country}'
+MSG91_PROMOTIONAL_ROUTE = 1
+MSG91_TRANSACTIONAL_ROUTE = 4
